import { describe, it, expect } from 'vitest'
import { Card } from '../card.js'

describe('Card', () => {
  it('debería inicializarse con estado vacío', () => {
    const card = new Card()
    const state = card.getState()

    expect(state.lastReview).toBeNull()
    expect(state.nextReview).toBeNull()
    expect(state.reviewCount).toBe(0)
    expect(state.metadata).toEqual({})
  })

  it('debería actualizar su estado', () => {
    const card = new Card()
    const currentDate = new Date('2024-03-20T12:00:00.000Z')
    const nextDate = new Date('2024-03-21T12:00:00.000Z')
    const metadata = { ef: 2.6 }

    card.updateReview(3, currentDate, nextDate, metadata)

    expect(card.getLastReview()).toEqual(currentDate)
    expect(card.getNextReview()).toEqual(nextDate)
    expect(card.getReviewCount()).toBe(1)
    expect(card.getMetadata()).toEqual(metadata)
  })

  it('debería reiniciar el contador cuando resetCount es true', () => {
    const card = new Card()
    const currentDate = new Date('2024-03-20T12:00:00.000Z')
    const nextDate = new Date('2024-03-21T12:00:00.000Z')
    const metadata = { ef: 2.6 }

    // Primera actualización
    card.updateReview(3, currentDate, nextDate, metadata)
    expect(card.getReviewCount()).toBe(1)

    // Segunda actualización con resetCount = true
    card.updateReview(2, nextDate, new Date('2024-03-22T12:00:00.000Z'), metadata, true)
    expect(card.getReviewCount()).toBe(0)
  })

  it('debería incrementar el contador cuando resetCount es false', () => {
    const card = new Card()
    const currentDate = new Date('2024-03-20T12:00:00.000Z')
    const nextDate = new Date('2024-03-21T12:00:00.000Z')
    const metadata = { ef: 2.6 }

    // Primera actualización
    card.updateReview(3, currentDate, nextDate, metadata)
    expect(card.getReviewCount()).toBe(1)

    // Segunda actualización con resetCount = false (por defecto)
    card.updateReview(4, nextDate, new Date('2024-03-22T12:00:00.000Z'), metadata)
    expect(card.getReviewCount()).toBe(2)
  })

  it('debería serializar y deserializar su estado', () => {
    const card = new Card()
    const currentDate = new Date('2024-03-20T12:00:00.000Z')
    const nextDate = new Date('2024-03-21T12:00:00.000Z')
    const metadata = { ef: 2.6 }

    card.updateReview(3, currentDate, nextDate, metadata)
    const serializedState = card.serialize()

    const newCard = new Card()
    newCard.deserialize(serializedState)

    expect(newCard.getLastReview()).toEqual(currentDate)
    expect(newCard.getNextReview()).toEqual(nextDate)
    expect(newCard.getReviewCount()).toBe(1)
    expect(newCard.getMetadata()).toEqual(metadata)
  })
}) 