import { describe, it, expect } from 'vitest'
import { Card } from '../card.js'
import { Scheduler } from '../scheduler.js'
import { SM2Scheduler } from '../algorithms/sm2.js'

describe('Scheduler', () => {
  it('debería lanzar error al intentar instanciar directamente', () => {
    expect(() => new Scheduler()).toThrow('Scheduler es una clase abstracta')
  })

  it('debería identificar correctamente las tarjetas que necesitan revisión', () => {
    const scheduler = new SM2Scheduler()
    const currentDate = new Date('2024-03-20T12:00:00.000Z')
    
    // Tarjeta 1: Necesita revisión (fecha de revisión pasada)
    const card1 = new Card()
    card1.setNextReview(new Date('2024-03-19T12:00:00.000Z')) // 1 día antes
    
    // Tarjeta 2: No necesita revisión (fecha de revisión futura)
    const card2 = new Card()
    card2.setNextReview(new Date('2024-03-21T12:00:00.000Z')) // 1 día después
    
    // Tarjeta 3: Necesita revisión (fecha de revisión pasada)
    const card3 = new Card()
    card3.setNextReview(new Date('2024-03-18T12:00:00.000Z')) // 2 días antes

    const cards = [card1, card2, card3]
    const cardsToReview = scheduler.getCardsToReview(cards, currentDate)

    // Debería devolver solo las tarjetas que necesitan revisión
    expect(cardsToReview).toHaveLength(2)
    
    // Debería ordenar por prioridad (las más antiguas primero)
    expect(cardsToReview[0]).toBe(card3) // La más antigua primero
    expect(cardsToReview[1]).toBe(card1) // La segunda más antigua después
  })
}) 