export class Card {
  constructor() {
    this.lastReview = null
    this.nextReview = null
    this.reviewCount = 0
    this.metadata = {}
  }

  getState() {
    return {
      lastReview: this.lastReview,
      nextReview: this.nextReview,
      reviewCount: this.reviewCount,
      metadata: { ...this.metadata }
    }
  }

  getLastReview() {
    return this.lastReview
  }

  getNextReview() {
    return this.nextReview
  }

  getReviewCount() {
    return this.reviewCount
  }

  getMetadata() {
    return this.metadata
  }

  setLastReview(date) {
    this.lastReview = date
  }

  setNextReview(date) {
    this.nextReview = date
  }

  setReviewCount(count) {
    this.reviewCount = count
  }

  setMetadata(metadata) {
    this.metadata = metadata
  }

  updateReview(quality, currentDate, nextDate, metadata = {}, resetCount = false) {
    this.lastReview = currentDate
    this.nextReview = nextDate
    this.reviewCount = resetCount ? 0 : this.reviewCount + 1
    this.metadata = {
      ...this.metadata,
      ...metadata
    }
  }

  serialize() {
    return JSON.stringify({
      lastReview: this.lastReview?.toISOString() || null,
      nextReview: this.nextReview?.toISOString() || null,
      reviewCount: this.reviewCount,
      metadata: this.metadata
    })
  }

  deserialize(serializedState) {
    const state = JSON.parse(serializedState)
    this.lastReview = state.lastReview ? new Date(state.lastReview) : null
    this.nextReview = state.nextReview ? new Date(state.nextReview) : null
    this.reviewCount = state.reviewCount || 0
    this.metadata = state.metadata || {}
  }
} 